 * ------------------------------------------------------------------ ;
 * -- DIAGNOSIS AND PROCEDURE MACROS for PSI module ICD-09 V6.0.2 --- ;
 *---              >>>  VERSION DATE JULY 2017  <<<               --- ;
 *------------------------------------------------------------------- ;
 
/*-- Macro ADDPRDAY ADDS PRDAY variables to input based on --*/
/*-- PRDAY setting in PSI_ALL_CONTROL.                     --*/
 %MACRO ADDPRDAY; 
    %IF &PRDAY EQ 1 %THEN PRDAY1-PRDAY&NPR. ;
 %MEND;

 /*-- Macro MDX searches entire DX vector for presence    --*/
 /*-- of diagnosis codes present in format passed (&FMT). --*/

 %MACRO MDX(FMT);

 (%DO I = 1 %TO &NDX.-1;
  (put(DX&I.,&FMT.) = '1') or
  %END;
  (put(DX&NDX.,&FMT.) = '1'))

 %MEND;

 /*-- Macro MDX1 searches ONLY first diagnosis code for    --*/
 /*-- presence of diagnosis codes in format passed (&FMT). --*/

 %MACRO MDX1(FMT);

 (put(DX1,&FMT.) = '1')

 %MEND;


 /*-- Macro MDX2 searches secondary diagnosis codes for  --*/
 /*-- presence of diagnosis codes in format passed       --*/

 %MACRO MDX2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (put(DX&I.,&FMT.) = '1') or
  %END;
  (put(DX&NDX.,&FMT.) = '1'))

 %MEND;

 /*-- Macro MDX2Q1 searches secondary diagnosis codes for the   --*/
 /*-- presence of diagnoses exempt or not POA in passed format  --*/

 %MACRO MDX2Q1(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (put(DX&I.,$poaxmpt.)='0' and put(DX&I.,&FMT.) = '1' and DXPOA&I. in ('N','U',' ','E','1','X')) or
  %END;
  (put(DX&NDX.,$poaxmpt.)='0' and put(DX&NDX.,&FMT.) = '1' and DXPOA&NDX. in ('N','U',' ','E','1','X')))

 %MEND;


 /*-- Macro MDX2Q2 searches secondary diagnosis codes for the   --*/
 /*-- presence of diagnoses POA in passed format (&FMT).        --*/

 %MACRO MDX2Q2(FMT);

 (%DO I = 2 %TO &NDX.-1;
  (put(DX&I.,$poaxmpt.)='0' and put(DX&I.,&FMT.) = '1' and DXPOA&I. in ('Y','W')) or
  (put(DX&I.,$poaxmpt.)='1' and put(DX&I.,&FMT.) = '1') or
  %END;
  (put(DX&NDX.,$poaxmpt.)='0' and put(DX&NDX.,&FMT.) = '1' and DXPOA&NDX. in ('Y','W')) or
  (put(DX&NDX.,$poaxmpt.)='1' and put(DX&NDX.,&FMT.) = '1') )

 %MEND;

 
 /*-- Macro MDR checks for presence of DRG value in format (&FMT). --*/

 %MACRO MDR(FMT);

 (put(put(DRG,Z3.),&FMT.) = '1')

 %MEND;

 /*-- Macro MPR searches entire PR vector for presence --*/
 /*-- of procedure codes in format passed (&FMT).      --*/

 %MACRO MPR(FMT);

 (%DO I = 1 %TO &NPR.-1;
  (put(PR&I.,&FMT.) = '1') or
  %END;
  (put(PR&NPR.,&FMT.) = '1'))

 %MEND;

 /*-- Macro MPR1 searches ONLY first procedure for presence --*/
 /*-- of procedure codes in format passed (&FMT).           --*/

 %MACRO MPR1(FMT);

 (put(PR1,&FMT.) = '1')

 %MEND;

 /*-- Macro MPR2 searches ONLY secondary procedures for the --*/
 /*-- presence of procedure codes in format passed (&FMT).  --*/

 %MACRO MPR2(FMT);

 (%DO I = 2 %TO &NPR.-1;
  (put(PR&I.,&FMT.) = '1') or
  %END;
  (put(PR&NPR.,&FMT.) = '1'))

 %MEND;

 /*-- Macro to count number of procedures on record --*/

 %MACRO MPRCNT(FMT);

    MPRCNT = 0; 
    %DO I = 1 %TO &NPR.;
       if put(PR&I.,&FMT.) = '1'    and
          put(PR&I.,$ORPROC_PSI.) = '1' then MPRCNT + 1;
    %END;

 %MEND;

 /*-- Macro to assign MPRDAY --*/

 %MACRO MPRDAY(FMT);

    MPRDAY = .;
    %DO I = 1 %TO &NPR.;
       if put(PR&I.,&FMT.) = '1' and PRDAY&I. gt .Z then do;
          if MPRDAY le .Z then MPRDAY = PRDAY&I;
          else if MPRDAY > PRDAY&I. then MPRDAY = PRDAY&I;
       end;
    %END;

 %MEND;

/*-- Macro to count OR procedures --*/

%MACRO ORCNT;

    ORCNT = 0;
    %DO I = 1 %TO &NPR.;
       if put(PR&I.,$ORPROC_PSI.) = '1' then ORCNT + 1;
    %END;

%MEND;

/*-- Macro to assign ORDAY --*/

%MACRO ORDAY(FMT);

    ORDAY = .;
    %DO I = 1 %TO &NPR.;
       if put(PR&I.,$ORPROC_PSI.) = '1' and
          put(PR&I.,&FMT.)    = '0' then do;
          if PRDAY&I. gt .Z then do;
             if ORDAY = . then ORDAY = PRDAY&I;
             else if ORDAY > PRDAY&I. then ORDAY = PRDAY&I;
          end;
       end;
    %END;

%MEND;

/*-- Macro Defsite used in remapping MDC --*/
%macro defsite;
 %do i = 1 %to &ndx.;
        if put(dx&i.,$s1FMT.)='1' then site_dx&i.='he';
   else if put(dx&i.,$s2FMT.)='1' then site_dx&i.='ch';
   else if put(dx&i.,$s3FMT.)='1' then site_dx&i.='ab';
   else if put(dx&i.,$s4FMT.)='1' then site_dx&i.='ki';
   else if put(dx&i.,$s5FMT.)='1' then site_dx&i.='ur';
   else if put(dx&i.,$s6FMT.)='1' then site_dx&i.='ps';
   else if put(dx&i.,$s7FMT.)='1' then site_dx&i.='ul';
   else if put(dx&i.,$s8FMT.)='1' then site_dx&i.='ll';
   else site_dx&i.=' ';
 %end;
 %mend defsite;